@@ -6,9 +6,18 @@ selectable but not run as default.
 
 # see https://docs.pytest.org/en/stable/example/parametrize.html
 
+
 def pytest_addoption(parser):
-    parser.addoption("--vulcan", action="store_true", help="run test for vulcan backends")
-    parser.addoption("--ibmq", action="store_true", help="run test for ibmq backends")
+    parser.addoption("--vulcan",
+                     action="store_true",
+                     help="run test for vulcan backends")
+    parser.addoption("--ibmq",
+                     action="store_true",
+                     help="run test for ibmq backends")
+    parser.addoption(
+        "--awswindows",
+        action="store_true",
+        help="run tests for braket schedule-window backends (ionq, rigetti)")
 
 
 # from some ideas in https://superorbit.al/journal/focusing-on-pytest/
@@ -16,10 +25,14 @@ def pytest_collection_modifyitems(session, config, items):
     deselected_items = []
     selected_items = []
     for item in items:
-        if "vulcan" in item.nodeid and not config.getoption("vulcan"):
+        if ("qcware/gpu_simulator" in item.nodeid or "qcware/gpu"
+                in item.nodeid) and not config.getoption("vulcan"):
             deselected_items.append(item)
         elif "ibmq" in item.nodeid and not config.getoption("ibmq"):
             deselected_items.append(item)
+        elif ("awsbraket/ionq" in item.nodeid or "awsbraket/rigetti"
+              in item.nodeid) and not config.getoption("awswindows"):
+            deselected_items.append(item)
         else:
             selected_items.append(item)
 
