@@ -3,11 +3,13 @@ import quasar
 import os
 import pytest
 from qcware.circuits.quasar_backend import QuasarBackend
+from qcware.exceptions import ApiCallExecutionError
 from pprint import pprint
 import numpy as np
 
 
 @pytest.mark.parametrize("backend,expected", [("qcware/cpu_simulator", True),
+                                              ("qcware/gpu_simulator", True),
                                               ("ibm/simulator", True),
                                               ("awsbraket/sv1", False),
                                               ("awsbraket/tn1", False)])
@@ -17,6 +19,7 @@ def test_has_run_statevector(backend: str, expected: bool):
 
 
 @pytest.mark.parametrize("backend,expected", [("qcware/cpu_simulator", True),
+                                              ("qcware/gpu_simulator", True),
                                               ("ibm/simulator", True),
                                               ("awsbraket/sv1", False),
                                               ("awsbraket/tn1", False)])
@@ -29,8 +32,9 @@ def test_has_statevector_input(backend: str, expected: bool):
     "backend",
     [
         ("qcware/cpu_simulator"),
+        ("qcware/gpu_simulator"),
         ("ibm/simulator"),
-        ("ibm/ibmq_qasm_simulator"),
+        ("ibmq:ibmq_qasm_simulator"),
         ("awsbraket/sv1"),
         ("awsbraket/tn1"),
         #        ("awsbraket/rigetti")
@@ -39,27 +43,49 @@ def test_run_measurement(backend):
     q = quasar.Circuit()
     q.H(0).CX(0, 1)
     b = QuasarBackend(backend)
-    result = b.run_measurement(circuit=q)
+    result = b.run_measurement(circuit=q, nmeasurement=100)
     assert isinstance(result, quasar.ProbabilityHistogram)
     assert isinstance(result.histogram, dict)
     assert 0 in result.histogram
-    # yeah, pretty fuzzy but I'll take it
-    assert abs(result.histogram[0] - 0.5) < 0.05
+    # yeah, pretty fuzzy but I'll take it; this is more or less a smoke test
+    assert abs(result.histogram[0] - 0.5) < 0.1
 
-    # now try with the backend
-    backend = QuasarBackend(backend)
-    result = backend.run_measurement(circuit=q)
-    assert isinstance(result, quasar.ProbabilityHistogram)
-    assert isinstance(result.histogram, dict)
-    assert 0 in result.histogram
-    # yeah, pretty fuzzy but I'll take it
-    assert abs(result.histogram[0] - 0.5) < 0.05
+
+@pytest.mark.parametrize("backend",
+                         (("awsbraket/ionq"), ("awsbraket/rigetti")))
+def test_smoke_backend_exception(backend):
+    """This is a 'smoke test' for having a NotImplementedError from a
+    backend. Accuracy doesn't matter here so long as the call gives a
+    NotImplementedError (since we call run_statevector on a backend without it)
+    """
+    q = quasar.Circuit()
+    q.H(0).CX(0, 1)
+    b = QuasarBackend(backend)
+    try:
+        result = b.run_statevector(circuit=q)
+    except ApiCallExecutionError as e:
+        assert str(e) == 'NotImplementedError: '
+        return
+    assert False
+
+
+@pytest.mark.parametrize("backend",
+                         (("awsbraket/ionq"), ("awsbraket/rigetti")))
+def test_smoke_rescheduled_backends(backend):
+    """This is another 'smoke test' for the backends that can be rescheduled; they
+    need to either raise a rescheduled exception or run
+    """
+    q = quasar.Circuit()
+    q.H(0).CX(0, 1)
+    b = QuasarBackend(backend)
+    result = b.run_measurement(circuit=q, nmeasurement=1)
 
 
 @pytest.mark.parametrize(
     "backend",
     [
         ("qcware/cpu_simulator"),
+        ("qcware/gpu_simulator"),
         #        ("awsbraket/rigetti")
     ])
 def test_run_statevector(backend):
@@ -67,5 +93,5 @@ def test_run_statevector(backend):
     q.H(0).CX(0, 1)
     b = QuasarBackend(backend)
     result = b.run_statevector(circuit=q)
-    val = np.complex(np.sqrt(2) / 2, 0)
+    val = complex(np.sqrt(2) / 2, 0)
     assert np.allclose(result, [val, 0, 0, val])
